Stan Math Library: stan/math/rev/scal/fun/as_bool.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

as_bool.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_AS_BOOL_HPP
2 #define STAN_MATH_REV_SCAL_FUN_AS_BOOL_HPP
3
4 #include <stan/math/rev/core.hpp>
5
6 namespace stan {
7 namespace math {
8
15 inline int as_bool(const var& v) {
16 return 0.0 != v.vi_->val_;
17 }
18
19 }
20 }
21 #endif
core.hpp
stan::math::as_bool
bool as_bool(const T x)
Return 1 if the argument is unequal to zero and 0 otherwise.
Definition: as_bool.hpp:14
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::vari::val_
const double val_
The value of this variable.
Definition: vari.hpp:38
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43

[ Stan Home Page ] © 2011–2016, Stan Development Team.